/**
 * Created by thinkzhan
 */

'use strict';

const path = require('path');
const webpack = require('webpack');
const ExtractTextPlugin = require('extract-text-webpack-plugin');

// px转rem loader?   
let px2rem = false; 
// rem值按100px转, 精确到小数点后8位
// 响应式可 引入libs/response.js动态修改html font-size
// response.js 100 * (clientWidth / 375) 自己修改 iphone6 375 font为100px
let px2rem_loader = px2rem ? `px2rem?remUnit=100&remPrecision=8!`: ''; 

module.exports = {
    // 入口
    entry: {
        main: ['babel-core/polyfill' , './src/main'],
         vendors: ['react', 'react-dom', 'react-router']
    },
    // 输出
    output: {
        path: path.resolve(__dirname, './dist')
    },
    // 加载器
    module: {
        loaders: [
            { test: /\.(jsx|js)?$/, loader: 'react-hot!babel?stage=0', exclude: /node_modules/ },
            { test: /\.css$/, loader: ExtractTextPlugin.extract('style','css!autoprefixer')},
            { test: /\.scss$/, loader: ExtractTextPlugin.extract('style',`css!${px2rem_loader}autoprefixer!sass?sourceMap`)},
            { test: /\.(gif|jpg|png|woff|svg|eot|ttf)\??.*$/, loader: 'url-loader?limit=8192'},
            { test: /\.(html|tpl)$/, loader: 'html-loader' } ,
            { test: require.resolve('zepto'), loader: 'imports?this=>window'},
            { test: require.resolve('isomorphic-fetch'), loader: 'imports?this=>window'},
        ]
    },

    resolve: {
        // require时省略的扩展名，如：require('module') 不需要module.js
        extensions: ['', '.js', '.jsx'],
        // 别名，可以直接使用别名来代表设定的路径以及其他
        alias: {
            libs: path.join(__dirname, './src/libs'),
            components: path.join(__dirname, './src/components'),
            images: path.join(__dirname, './src/images'),
            styles: path.join(__dirname, './src/styles'),
            commons:  path.join(__dirname, '../common')
        }
    },
    plugins: [
        new webpack.NoErrorsPlugin(),
        new webpack.ProvidePlugin({
          $: 'zepto',
          zepto: 'zepto',
          'window.Zepto': 'zepto',

          // $: 'jquery',
          // jquery: 'jquery',
          // 'window.jQuery': 'jquery'
        }),
         new webpack.ProvidePlugin({
          fetch: 'isomorphic-fetch',
          'window.fetch': 'isomorphic-fetch',

          // $: 'jquery',
          // jquery: 'jquery',
          // 'window.jQuery': 'jquery'
        }),
        
    ],
    // externals: {
    //     'jquery': 'jQuery'j'
    // },
};
