/**
  * 表单校验
    1.校验汉字 isValidWord
    2.校验邮箱 isValidMail
    3.校验网址 isValidUrl
    4.校验手机号 isValidPhone
    5.校验营业执照注册码 isValidBusCode
    6.校验身份证 isValidIdCard
    7.校验字符长度 limitChar
**/

// 1.校验汉字
let isValidWord(word) => {
    return /^[\u4E00-\u9FA5\uF900-\uFA2D \s]{1,10}$/.test(word),
}
// 2.校验邮箱
let isValidMail(email) => {
    var emailReg=/^([a-zA-Z0-9]+[_|\-|\.]?)*[a-zA-Z0-9]+@([a-zA-Z0-9]+[_|\-|\.]?)*[a-zA-Z0-9]+(\.[a-zA-Z]{2,3})+$/;
    if(emailReg.test(email))
        return true;
    else
        return false;
}
// 3.校验网址
let isValidUrl(url) => {
    var urlReg= /^(http|ftp|https):\/\/[\w\-_]+(\.[\w\-_]+)+([\w\-\.,@?^=%&amp;:/~\+#]*[\w\-\@?^=%&amp;/~\+#])?$/;
    if(urlReg.test(url))
        return true;
    else
        return false;
}
// 4.校验手机号
let isValidPhone(phone) => {
    return /^((0\d{2,3}))(\d{7,8})(-?(\d{3,}))?$/.test($.trim(phone));
}
// 5.校验营业执照注册码
let isValidBusCode(busCode) => {
    var ret=false;
    var reg = /^[0-9]{15}$/;
    if(reg.test(busCode)){
        var sum=0;
        var s=[];
        var p=[];
        var a=[];
        var m=10;
        p[0]=m;
        for(var i=0;i<busCode.length;i++)
        {
            a[i]=parseInt(busCode.substring(i,i+1),m);
            s[i]=(p[i]%(m+1))+a[i];
            if(0==s[i]%m)
            {
                p[i+1]=10*2;
            }
            else
            {
                p[i+1]=(s[i]%m)*2;
            }
        }
        if(1==(s[14]%m))
        {
            ret=true;
        }
    }
    else if(/^[0-9A-Z]{18}$/.test(busCode))
    {
        ret = true;
    }
    return ret;
}
// 6.校验身份证
let isValidIdCard(idCard) =>{
    //15位和18位身份证号码的正则表达式
    var regIdCard=/^(^[1-9]\d{7}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}$)|(^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])((\d{4})|\d{3}[Xx])$)$/;

    //如果通过该验证，说明身份证格式正确，但准确性还需计算
    if(regIdCard.test(idCard)){
        if(idCard.length==18){
            var idCardWi=new Array( 7, 9, 10, 5, 8, 4, 2, 1, 6, 3, 7, 9, 10, 5, 8, 4, 2 ); //将前17位加权因子保存在数组里
            var idCardY=new Array( 1, 0, 10, 9, 8, 7, 6, 5, 4, 3, 2 ); //这是除以11后，可能产生的11位余数、验证码，也保存成数组
            var idCardWiSum=0; //用来保存前17位各自乖以加权因子后的总和
            for(var i=0;i<17;i++){
                idCardWiSum+=idCard.substring(i,i+1)*idCardWi[i];
            }

            var idCardMod=idCardWiSum%11;//计算出校验码所在数组的位置
            var idCardLast=idCard.substring(17);//得到最后一位身份证号码

            //如果等于2，则说明校验码是10，身份证号码最后一位应该是X
            if(idCardMod==2){
                if(idCardLast=="X"||idCardLast=="x"){
                    return true;
                }else{
                    return false;
                }
            }else{
                //用计算出的验证码与最后一位身份证号码匹配，如果一致，说明通过，否则是无效的身份证号码
                if(idCardLast==idCardY[idCardMod]){
                    return true;
                }else{
                    return false;
                }
            }
        }
    }else{
        return false;
    }
}

// 7.校验字符长度： 输入，最小字符数，最大字符数
let limitChar = (str, min, max) => {
  if (str.length < 1) return false; //null
  //if( /^[a-zA-Z0-9]/.test(str)) return false; //数字字母开头
  var ta = str.split(""),
    str_l = 0;
  var str_fa = Number(ta[0].charCodeAt());
  // if((str_fa>=65&&str_fa<=90)||(str_fa>=97&&str_fa<=122)||(str_fa>255))
  // {
  for (var i = 0; i <= ta.length - 1; i++) {
    str_l++;
    if (Number(ta[i].charCodeAt()) > 255) {
      str_l++;
    }
  }
  if (str_l >= min && str_l <= max) {
    return true;
  }
  //  }
  return false;
}
