/**
 * Created by thinkzhan
 */
'use strict';

const webpack = require('webpack');
const config = require('./webpack.base.config');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const ExtractTextPlugin = require('extract-text-webpack-plugin');
const fs = require('fs');

config.devtool = '#source-map';                             // source-map
config.output.publicPath = '/dist/';                        // 不要写成./,内存加载，不然server不会自动刷新                     // 资源路径
config.output.filename = '[name].js';                       // 入口js命名
config.output.chunkFilename = '[name].chunk.js';            // 路由js命名

config.plugins = (config.plugins || []).concat([
    new ExtractTextPlugin("[name].css",{ allChunks : true,resolve : ['modules'] }),             // 提取CSS
    new webpack.optimize.CommonsChunkPlugin('vendors', 'vendors.js'),                           // 提取第三方库
    new HtmlWebpackPlugin({                                                                     // 构建html文件
        filename: '../index_dev.html',
        template: './src/template/index.html',
        inject: 'body'
    })
]);

// npm run init 时不需要热加载
if(process.argv[2] !== '--config') {
    const WebpackDevServer = require('webpack-dev-server');
    const BrowserSyncPlugin = require('browser-sync-webpack-plugin');

    const localhost_url = '10.0.120.220' ; // 尽量不使用127或localhost，方便wap热加载调试
    const dev_server_port = '8083'; // 不要用8080，跟browserSync调试冲突

    let entrys = config.entry;

    for(let i in entrys) {
        console.log(entrys[i]);
        entrys[i].unshift(`webpack-dev-server/client?http://${localhost_url}:${dev_server_port}`, "webpack/hot/dev-server");
    }
    config.plugins.push(new webpack.HotModuleReplacementPlugin());

    // 多端调试利器browserSync！ pc开发可注释掉此部分配置
    // 效果: 代码修改，pc和wap可同步刷新，并且可remote debug wap页面
    // 使用：访问代理的3000端口而非webpack devserver的端口
    //    http://1127.0.0.1:3001/remote-debug ，现在wap刷新再打开远程调试
    config.plugins.push( new BrowserSyncPlugin({
        host: `${localhost_url}`,
        port: 3000,
        // proxy webpack dev server
        proxy: `http://${localhost_url}:${dev_server_port}/`
      },
      { // browserSync本身可热加载，阻止，把此工作交还给webpack devserver
        reload: false
      }
    ));

    //启动服务
    new WebpackDevServer(webpack(config), {
        publicPath: config.output.publicPath,
        hot:true,
       
        historyApiFallback: {
          index: './index_dev.html'
        },
        //proxy: require('../API/{proj}/mock-rule')
    }).listen(dev_server_port); 

}

// // 写入环境变量
// fs.open('./src/config/env.js', 'w', function (err, fd) {
//     var buf = 'module.exports = "development";';
//     fs.write(fd,buf,0,buf.length,0,function(err,written,buffer){});
// });

module.exports = config;